@@ -34,10 +34,10 @@ class _shareData(object):
 
     def getDataInFile(self, fileName='', lenData=7):
         """Get data list from file"""
-        return map(lambda x: x[:lenData],
-                   filter(lambda x: len(x) >= lenData,
-                          map(lambda x: x.rstrip().split(":"),
-                              open(fileName))))
+        with open(fileName) as f:
+            return map(lambda x: x[:lenData],
+                       filter(lambda x: len(x) >= lenData,
+                              map(lambda x: x.rstrip().split(":"), f)))
 
 
 class migrateGroups(_shareData):
